import unittest
from six import text_type, u, b, PY2, PY3
from opentok import Client, Session, __version__
import httpretty
import json
import textwrap
from expects import *

from .validate_jwt import validate_jwt_header


class OpenTokSignalTest(unittest.TestCase):
    def setUp(self):
        self.api_key = u("123456")
        self.api_secret = u("1234567890abcdef1234567890abcdef1234567890")
        self.opentok = Client(self.api_key, self.api_secret)
        self.session_id = u("SESSIONID")

    @httpretty.activate
    def test_signal(self):
        data = {u("type"): u("type test"), u("data"): u("test data")}

        httpretty.register_uri(
            httpretty.POST,
            u("https://api.opentok.com/v2/project/{0}/session/{1}/signal").format(
                self.api_key, self.session_id
            ),
            body=textwrap.dedent(
                u(
                    """\
                        {
                            "type": "type test",
                            "data": "test data"
                        }
                    """
                )
            ),
            status=204,
            content_type=u("application/json"),
        )

        self.opentok.send_signal(self.session_id, data)

        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )
        # non-deterministic json encoding. have to decode to test it properly
        if PY2:
            body = json.loads(httpretty.last_request().body)
        if PY3:
            body = json.loads(httpretty.last_request().body.decode("utf-8"))
        expect(body).to(have_key(u("type"), u("type test")))
        expect(body).to(have_key(u("data"), u("test data")))

    @httpretty.activate
    def test_signal_with_connection_id(self):
        data = {u("type"): u("type test"), u("data"): u("test data")}

        connection_id = u("da9cb410-e29b-4c2d-ab9e-fe65bf83fcaf")

        httpretty.register_uri(
            httpretty.POST,
            u(
                "https://api.opentok.com/v2/project/{0}/session/{1}/connection/{2}/signal"
            ).format(self.api_key, self.session_id, connection_id),
            body=textwrap.dedent(
                u(
                    """\
                        {
                            "type": "type test",
                            "data": "test data"
                        }
                    """
                )
            ),
            status=204,
            content_type=u("application/json"),
        )

        self.opentok.send_signal(self.session_id, data, connection_id)

        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )
        # non-deterministic json encoding. have to decode to test it properly
        if PY2:
            body = json.loads(httpretty.last_request().body)
        if PY3:
            body = json.loads(httpretty.last_request().body.decode("utf-8"))
        expect(body).to(have_key(u("type"), u("type test")))
        expect(body).to(have_key(u("data"), u("test data")))



import unittest
from six import u
from opentok import Client, Stream, StreamList, __version__, SetStreamClassError
import httpretty
import textwrap
from expects import *

from .validate_jwt import validate_jwt_header


class OpenTokStreamTest(unittest.TestCase):
    def setUp(self):
        self.api_key = u("123456")
        self.api_secret = u("1234567890abcdef1234567890abcdef1234567890")
        self.opentok = Client(self.api_key, self.api_secret)
        self.session_id = u("SESSIONID")
        self.stream_id = u("8b732909-0a06-46a2-8ea8-074e64d43422")

    @httpretty.activate
    def test_get_stream(self):
        stream = Stream(
            {
                u("id"): u("8b732909-0a06-46a2-8ea8-074e64d43422"),
                u("videoType"): u("camera"),
                u("name"): u(""),
                u("layoutClassList"): ["full"],
            }
        )

        httpretty.register_uri(
            httpretty.GET,
            u("https://api.opentok.com/v2/project/{0}/session/{1}/stream/{2}").format(
                self.api_key, self.session_id, self.stream_id
            ),
            body=textwrap.dedent(
                u(
                    """\
                        {
                            "id": "8b732909-0a06-46a2-8ea8-074e64d43422",
                            "videoType": "camera",
                            "name": "",
                            "layoutClassList": ["full"]
                        }
                    """
                )
            ),
            status=200,
            content_type=u("application/json"),
        )

        stream_response = self.opentok.get_stream(self.session_id, self.stream_id)
        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )
        expect(stream_response).to(be_an(Stream))
        expect(stream_response).to(have_property(u("id"), stream.id))
        expect(stream_response).to(have_property(u("videoType"), stream.videoType))
        expect(stream_response).to(have_property(u("name"), stream.name))
        expect(stream_response).to(
            have_property(u("layoutClassList"), stream.layoutClassList)
        )
        expect(list(stream_response.layoutClassList)).to(have_length(1))

    @httpretty.activate
    def test_get_stream_with_name(self):
        stream = Stream(
            {
                u("id"): u("8b732909-0a06-46a2-8ea8-074e64d43422"),
                u("videoType"): u("camera"),
                u("name"): u("stream name"),
                u("layoutClassList"): ["full"],
            }
        )

        httpretty.register_uri(
            httpretty.GET,
            u("https://api.opentok.com/v2/project/{0}/session/{1}/stream/{2}").format(
                self.api_key, self.session_id, self.stream_id
            ),
            body=textwrap.dedent(
                u(
                    """\
                        {
                            "id": "8b732909-0a06-46a2-8ea8-074e64d43422",
                            "videoType": "camera",
                            "name": "stream name",
                            "layoutClassList": ["full"]
                        }
                    """
                )
            ),
            status=200,
            content_type=u("application/json"),
        )

        stream_response = self.opentok.get_stream(self.session_id, self.stream_id)
        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )
        expect(stream_response).to(be_an(Stream))
        expect(stream_response).to(have_property(u("id"), stream.id))
        expect(stream_response).to(have_property(u("videoType"), stream.videoType))
        expect(stream_response).to(have_property(u("name"), stream.name))
        expect(stream_response).to(
            have_property(u("layoutClassList"), stream.layoutClassList)
        )
        expect(list(stream_response.layoutClassList)).to(have_length(1))

    @httpretty.activate
    def test_get_stream_list(self):
        httpretty.register_uri(
            httpretty.GET,
            u("https://api.opentok.com/v2/project/{0}/session/{1}/stream").format(
                self.api_key, self.session_id
            ),
            body=textwrap.dedent(
                u(
                    """\
                        {
                            "count": 2,
                            "items": [
                                {
                                "id": "8b732909-0a06-46a2-8ea8-074e64d43422",
                                "videoType": "camera",
                                "name": "stream1",
                                "layoutClassList": ["full"]
                                },
                                {
                                "id": "7b732909-0a06-46a2-8ea8-074e64d43423",
                                "videoType": "camera",
                                "name": "stream2",
                                "layoutClassList": ["full"]
                                }
                            ]
                        }
                    """
                )
            ),
            status=200,
            content_type=u("application/json"),
        )

        stream_list = self.opentok.list_streams(self.session_id)
        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )
        expect(stream_list).to(be_an(StreamList))
        expect(stream_list).to(have_property(u("count"), 2))
        expect(list(stream_list.items)).to(have_length(2))

    @httpretty.activate
    def test_set_stream_class_lists(self):
        """Test set stream class functionality"""
        payload = [
            {
                "id": "7b09ec3c-26f9-43d7-8197-f608f13d4fb6",
                "layoutClassList": ["focus"],
            },
            {"id": "567bc941-6ea0-4c69-97fc-70a740b68976", "layoutClassList": ["top"]},
            {
                "id": "307dc941-0450-4c09-975c-705740d08970",
                "layoutClassList": ["bottom"],
            },
        ]

        httpretty.register_uri(
            httpretty.PUT,
            u("https://api.opentok.com/v2/project/{0}/session/{1}/stream").format(
                self.api_key, self.session_id
            ),
            status=200,
            content_type=u("application/json"),
        )

        self.opentok.set_stream_class_lists(self.session_id, payload)

        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )

    @httpretty.activate
    def test_set_stream_class_lists_throws_exception(self):
        """Test invalid request in set stream class list"""

        # invalid payload
        payload = [{"id": "7b09ec3c-26f9-43d7-8197-f608f13d4fb6"}]

        httpretty.register_uri(
            httpretty.PUT,
            u("https://api.opentok.com/v2/project/{0}/session/{1}/stream").format(
                self.api_key, self.session_id
            ),
            status=400,
            content_type=u("application/json"),
        )

        self.assertRaises(
            SetStreamClassError,
            self.opentok.set_stream_class_lists,
            self.session_id,
            payload,
        )



import pytest
import unittest
from six import text_type, u
import time
import datetime
import calendar

from opentok import Client, Roles, OpenTokException

from .helpers import token_decoder, token_signature_validator


class OpenTokTokenGenerationTest(unittest.TestCase):
    def setUp(self):
        self.api_key = u("123456")
        self.api_secret = u("1234567890abcdef1234567890abcdef1234567890")
        self.session_id = u(
            "1_MX4xMjM0NTZ-flNhdCBNYXIgMTUgMTQ6NDI6MjMgUERUIDIwMTR-MC40OTAxMzAyNX4"
        )
        self.opentok = Client(self.api_key, self.api_secret)

    def test_generate_plain_token_t1(self):
        token = self.opentok.generate_token(self.session_id, use_jwt=False)
        assert isinstance(token, text_type)
        assert token_decoder(token)[u("session_id")] == self.session_id
        assert token_signature_validator(token, self.api_secret)

    def test_generate_plain_token_jwt(self):
        token = self.opentok.generate_token(self.session_id)
        assert isinstance(token, text_type)
        assert token_decoder(token, self.api_secret)[u("session_id")] == self.session_id

    def test_generate_plain_token_jwt_vonage_wrapper(self):
        self.api_secret = './tests/fake_data/dummy_private_key.txt'
        vonage_wrapper = Client(self.api_key, self.api_secret)
        public_key = ""
        with open('./tests/fake_data/dummy_public_key.txt', 'r') as file:
            public_key = file.read()

        token = vonage_wrapper.generate_token(self.session_id)
        assert isinstance(token, text_type)
        assert token_decoder(token, public_key)[u("session_id")] == self.session_id

    def test_generate_role_token(self):
        token = self.opentok.generate_token(self.session_id, Roles.moderator)
        assert isinstance(token, text_type)
        assert token_decoder(token, self.api_secret)[u("role")] == Roles.moderator.value

        token = self.opentok.generate_token(self.session_id, role=Roles.moderator)
        assert isinstance(token, text_type)
        assert token_decoder(token, self.api_secret)[u("role")] == Roles.moderator.value

        token = self.opentok.generate_token(self.session_id, Roles.publisher_only)
        assert token_decoder(token, self.api_secret)["role"] == Roles.publisher_only.value

    def test_generate_expires_token(self):
        # an integer is a valid argument
        expire_time = int(time.time()) + 100
        token = self.opentok.generate_token(self.session_id, expire_time=expire_time)
        assert isinstance(token, text_type)
        print(token_decoder(token, self.api_secret))
        assert token_decoder(token, self.api_secret)[u("exp")] == expire_time
        # anything that can be coerced into an integer is also valid
        expire_time = text_type(int(time.time()) + 100)
        token = self.opentok.generate_token(self.session_id, expire_time=expire_time)
        assert isinstance(token, text_type)
        assert token_decoder(token, self.api_secret)[u("exp")] == int(expire_time)
        # a datetime object is also valid
        expire_time = datetime.datetime.fromtimestamp(
            time.time(), datetime.timezone.utc
        ) + datetime.timedelta(days=1)
        token = self.opentok.generate_token(self.session_id, expire_time=expire_time)
        assert isinstance(token, text_type)
        assert token_decoder(token, self.api_secret)[u("exp")] == calendar.timegm(
            expire_time.utctimetuple()
        )

    def test_generate_data_token(self):
        data = u("name=Johnny")
        token = self.opentok.generate_token(self.session_id, data=data)
        assert isinstance(token, text_type)
        assert token_decoder(token, self.api_secret)[u("connection_data")] == data

    def test_generate_initial_layout_class_list(self):
        initial_layout_class_list = [u("focus"), u("small")]
        token = self.opentok.generate_token(
            self.session_id, initial_layout_class_list=initial_layout_class_list
        )
        assert isinstance(token, text_type)
        assert sorted(
            token_decoder(token, self.api_secret)[u("initial_layout_class_list")].split(
                u(" ")
            )
        ) == sorted(initial_layout_class_list)

    def test_generate_no_data_token(self):
        token = self.opentok.generate_token(self.session_id)
        assert isinstance(token, text_type)
        assert u("connection_data") not in token_decoder(token, self.api_secret)

    def test_does_not_generate_token_without_params(self):
        with pytest.raises(TypeError):
            self.opentok.generate_token()

    def test_does_not_generate_token_without_session(self):
        with pytest.raises(TypeError):
            self.opentok.generate_token(role=Roles.subscriber)

    def test_does_not_generate_token_invalid_session(self):
        with pytest.raises(OpenTokException):
            self.opentok.generate_token(u("NOT A REAL SESSIONID"))

    def test_does_not_generate_token_without_api_key_match(self):
        with pytest.raises(OpenTokException):
            # this session_id has the wrong api_key
            session_id = u(
                "1_MX42NTQzMjF-flNhdCBNYXIgMTUgMTQ6NDI6MjMgUERUIDIwMTR-MC40OTAxMzAyNX4"
            )
            self.opentok.generate_token(session_id)



import unittest
from six import u
from expects import *
import httpretty

from opentok import Client, __version__, AuthError, ForceDisconnectError
from .validate_jwt import validate_jwt_header


class OpenTokForceDisconnectTest(unittest.TestCase):
    """" Class that contains test for force disconnect functionality """

    def setUp(self):
        self.api_key = u("123456")
        self.api_secret = u("1234567890abcdef1234567890abcdef1234567890")
        self.opentok = Client(self.api_key, self.api_secret)
        self.session_id = u("SESSIONID")
        self.connection_id = u("CONNECTIONID")

    @httpretty.activate
    def test_force_disconnect(self):
        """ Method to test force disconnect functionality using an Client instance """

        httpretty.register_uri(
            httpretty.DELETE,
            u(
                "https://api.opentok.com/v2/project/{0}/session/{1}/connection/{2}"
            ).format(self.api_key, self.session_id, self.connection_id),
            status=204,
            content_type=u("application/json"),
        )

        self.opentok.force_disconnect(self.session_id, self.connection_id)

        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )

    @httpretty.activate
    def test_throws_force_disconnect_exception(self):
        """ This method should throw a ForceDisconnectError """

        httpretty.register_uri(
            httpretty.DELETE,
            u(
                "https://api.opentok.com/v2/project/{0}/session/{1}/connection/{2}"
            ).format(self.api_key, self.session_id, self.connection_id),
            status=400,
            content_type=u("application/json"),
        )

        self.assertRaises(
            ForceDisconnectError,
            self.opentok.force_disconnect,
            self.session_id,
            self.connection_id,
        )

    @httpretty.activate
    def test_throws_auth_exception(self):
        """ This method should throw an AuthError """

        httpretty.register_uri(
            httpretty.DELETE,
            u(
                "https://api.opentok.com/v2/project/{0}/session/{1}/connection/{2}"
            ).format(self.api_key, self.session_id, self.connection_id),
            status=403,
            content_type=u("application/json"),
        )

        self.assertRaises(
            AuthError,
            self.opentok.force_disconnect,
            self.session_id,
            self.connection_id,
        )



from setuptools import setup, find_packages
import codecs
import os
import re

here = os.path.abspath(os.path.dirname(__file__))


# Read the version number from a source file.
# Why read it, and not import?
# see https://groups.google.com/d/topic/pypa-dev/0PkjVpcxTzQ/discussion
def find_version(*file_paths):
    # Open in Latin-1 so that we avoid encoding errors.
    # Use codecs.open for Python 2 compatibility
    with codecs.open(os.path.join(here, *file_paths), "r", "latin1") as f:
        version_file = f.read()

    # The version line must have the form
    # __version__ = 'ver'
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


# Get the long description from the relevant file
with codecs.open("README.rst", encoding="utf-8") as f:
    long_description = f.read()

install_requires = ["requests", "six", "pytz", "pyjwt[crypto]>=1.6.4", "rsa>=4.7"]

setup(
    name="opentok",
    version=find_version("opentok", "version.py"),
    description="OpenTok server-side SDK",
    long_description_content_type="text/x-rst",
    url="https://github.com/opentok/Opentok-Python-SDK/",
    long_description=long_description,
    author="TokBox, Inc.",
    author_email="support@tokbox.com",
    license="LICENSE.txt",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Telecommunications Industry",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Topic :: Communications",
        "Topic :: Communications :: Chat",
        "Topic :: Communications :: Conferencing",
        "Topic :: Multimedia :: Video :: Capture",
        "Topic :: Multimedia :: Video :: Display",
        "Topic :: Multimedia :: Sound/Audio :: Players",
        "Topic :: Multimedia :: Sound/Audio :: Capture/Recording",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords="video chat tokbox tok opentok python media webrtc archiving realtime",
    packages=find_packages(exclude=["contrib", "docs", "tests*"]),
    install_requires=install_requires,
    include_package_data=True,
)



import pytest
import unittest
from six import u
import httpretty
import requests

from opentok import Client, OpenTokException


def _raise_timeout(*args):
    raise requests.Timeout("Timeout occurred")


class OpenTokSessionCreationTest(unittest.TestCase):
    def setUp(self):
        self.api_key = u("123456")
        self.api_secret = u("1234567890abcdef1234567890abcdef1234567890")
        httpretty.enable()
        httpretty.register_uri(
            httpretty.POST,
            u("https://api.opentok.com/session/create"),
            body=_raise_timeout,
            status=200,
            content_type=u("text/xml"),
        )

    def tearDown(self):
        httpretty.disable()

    @pytest.mark.filterwarnings("ignore::pytest.PytestUnhandledThreadExceptionWarning")
    def test_timeout(self):
        with pytest.raises(OpenTokException):
            opentok = Client(self.api_key, self.api_secret, timeout=1)
            opentok.create_session()



import unittest
import textwrap
import httpretty

from six import u
from expects import *
from opentok import Client, SipCall, __version__

from .validate_jwt import validate_jwt_header


class OpenTokSipCallTest(unittest.TestCase):
    def setUp(self):
        self.api_key = u("123456")
        self.api_secret = u("1234567890abcdef1234567890abcdef1234567890")
        self.opentok = Client(self.api_key, self.api_secret)

        self.session_id = u("SESSIONID")
        self.token = u("TOKEN")
        self.sip_uri = u("sip:user@sip.partner.com;transport=tls")

    @httpretty.activate
    def test_sip_call_with_required_parameters(self):
        """
        Test dial() method using just the required parameters: session_id, token, sip_uri
        """
        sip_call = SipCall(
            {
                u("id"): u("b0a5a8c7-dc38-459f-a48d-a7f2008da853"),
                u("connectionId"): u("e9f8c166-6c67-440d-994a-04fb6dfed007"),
                u("streamId"): u("482bce73-f882-40fd-8ca5-cb74ff416036"),
            }
        )

        httpretty.register_uri(
            httpretty.POST,
            u("https://api.opentok.com/v2/project/{0}/dial").format(self.api_key),
            body=textwrap.dedent(
                u(
                    """\
                        {
                            "id": "b0a5a8c7-dc38-459f-a48d-a7f2008da853",
                            "connectionId": "e9f8c166-6c67-440d-994a-04fb6dfed007",
                            "streamId": "482bce73-f882-40fd-8ca5-cb74ff416036"
                        }
                    """
                )
            ),
            status=200,
            content_type=u("application/json"),
        )

        sip_call_response = self.opentok.dial(self.session_id, self.token, self.sip_uri)
        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )
        expect(sip_call_response).to(be_an(SipCall))
        expect(sip_call_response).to(have_property(u("id"), sip_call.id))
        expect(sip_call_response).to(
            have_property(u("connectionId"), sip_call.connectionId)
        )
        expect(sip_call_response).to(have_property(u("streamId"), sip_call.streamId))

    @httpretty.activate
    def test_sip_call_with_aditional_options(self):
        """
        Test dial() method with aditional options
        """
        sip_call = SipCall(
            {
                u("id"): u("b0a5a8c7-dc38-459f-a48d-a7f2008da853"),
                u("connectionId"): u("e9f8c166-6c67-440d-994a-04fb6dfed007"),
                u("streamId"): u("482bce73-f882-40fd-8ca5-cb74ff416036"),
            }
        )

        httpretty.register_uri(
            httpretty.POST,
            u("https://api.opentok.com/v2/project/{0}/dial").format(self.api_key),
            body=textwrap.dedent(
                u(
                    """\
                        {
                            "id": "b0a5a8c7-dc38-459f-a48d-a7f2008da853",
                            "connectionId": "e9f8c166-6c67-440d-994a-04fb6dfed007",
                            "streamId": "482bce73-f882-40fd-8ca5-cb74ff416036"
                        }
                    """
                )
            ),
            status=200,
            content_type=u("application/json"),
        )

        # aditional options to establish the sip call
        options = {
            "from": "from@example.com",
            "headers": {"headerKey": "headerValue"},
            "auth": {"username": "username", "password": "password"},
            "secure": True,
            "observeForceMute": True,
            "video": True,
            "streams": ["stream-id-1", "stream-id-2"],
        }

        sip_call_response = self.opentok.dial(
            self.session_id, self.token, self.sip_uri, options
        )
        validate_jwt_header(self, httpretty.last_request().headers[u("x-opentok-auth")])
        expect(httpretty.last_request().headers[u("user-agent")]).to(
            contain(u("OpenTok-Python-SDK/") + __version__)
        )
        expect(httpretty.last_request().headers[u("content-type")]).to(
            equal(u("application/json"))
        )
        expect(sip_call_response).to(be_an(SipCall))
        expect(sip_call_response).to(have_property(u("id"), sip_call.id))
        expect(sip_call_response).to(
            have_property(u("connectionId"), sip_call.connectionId)
        )
        expect(sip_call_response).to(have_property(u("streamId"), sip_call.streamId))
        assert (
            b'"streams": ["stream-id-1", "stream-id-2"]}' in httpretty.last_request().body
        )
